==> zio-aws-route53recoverycontrolconfig_2.12-5.17.130.8-sources.jar: zio/aws/route53recoverycontrolconfig/model/NewGatingRule.scala <==
package zio.aws.route53recoverycontrolconfig.model
import java.lang.Integer
import zio.aws.route53recoverycontrolconfig.model.primitives.{
  __integer,
  __stringMin1Max64PatternS,
  __stringMin1Max256PatternAZaZ09
}
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class NewGatingRule(
    controlPanelArn: __stringMin1Max256PatternAZaZ09,
    gatingControls: Iterable[__stringMin1Max256PatternAZaZ09],
    name: __stringMin1Max64PatternS,
    ruleConfig: zio.aws.route53recoverycontrolconfig.model.RuleConfig,
    targetControls: Iterable[__stringMin1Max256PatternAZaZ09],
    waitPeriodMs: __integer
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.route53recoverycontrolconfig.model.NewGatingRule = {
    import NewGatingRule.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.NewGatingRule
      .builder()
      .controlPanelArn(controlPanelArn: java.lang.String)
      .gatingControls(gatingControls.map { item =>
        item: java.lang.String
      }.asJavaCollection)
      .name(name: java.lang.String)
      .ruleConfig(ruleConfig.buildAwsValue())
      .targetControls(targetControls.map { item =>
        item: java.lang.String
      }.asJavaCollection)
      .waitPeriodMs(waitPeriodMs: Integer)
      .build()
  }
  def asReadOnly
      : zio.aws.route53recoverycontrolconfig.model.NewGatingRule.ReadOnly =
    zio.aws.route53recoverycontrolconfig.model.NewGatingRule
      .wrap(buildAwsValue())
}
object NewGatingRule {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.NewGatingRule
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.route53recoverycontrolconfig.model.NewGatingRule =
      zio.aws.route53recoverycontrolconfig.model.NewGatingRule(
        controlPanelArn,
        gatingControls,
        name,
        ruleConfig.asEditable,
        targetControls,
        waitPeriodMs
      )
    def controlPanelArn: __stringMin1Max256PatternAZaZ09
    def gatingControls: List[__stringMin1Max256PatternAZaZ09]
    def name: __stringMin1Max64PatternS
    def ruleConfig
        : zio.aws.route53recoverycontrolconfig.model.RuleConfig.ReadOnly
    def targetControls: List[__stringMin1Max256PatternAZaZ09]
    def waitPeriodMs: __integer
    def getControlPanelArn: ZIO[Any, Nothing, __stringMin1Max256PatternAZaZ09] =
      ZIO.succeed(controlPanelArn)
    def getGatingControls
        : ZIO[Any, Nothing, List[__stringMin1Max256PatternAZaZ09]] =
      ZIO.succeed(gatingControls)
    def getName: ZIO[Any, Nothing, __stringMin1Max64PatternS] =
      ZIO.succeed(name)
    def getRuleConfig: ZIO[
      Any,
      Nothing,
      zio.aws.route53recoverycontrolconfig.model.RuleConfig.ReadOnly
    ] = ZIO.succeed(ruleConfig)
    def getTargetControls
        : ZIO[Any, Nothing, List[__stringMin1Max256PatternAZaZ09]] =
      ZIO.succeed(targetControls)
    def getWaitPeriodMs: ZIO[Any, Nothing, __integer] =
      ZIO.succeed(waitPeriodMs)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.NewGatingRule
  ) extends zio.aws.route53recoverycontrolconfig.model.NewGatingRule.ReadOnly {
    override val controlPanelArn: __stringMin1Max256PatternAZaZ09 =
      impl.controlPanelArn(): __stringMin1Max256PatternAZaZ09
    override val gatingControls: List[__stringMin1Max256PatternAZaZ09] = impl
      .gatingControls()
      .asScala
      .map { item =>
        item: __stringMin1Max256PatternAZaZ09
      }
      .toList
    override val name: __stringMin1Max64PatternS =
      impl.name(): __stringMin1Max64PatternS
    override val ruleConfig
        : zio.aws.route53recoverycontrolconfig.model.RuleConfig.ReadOnly =
      zio.aws.route53recoverycontrolconfig.model.RuleConfig
        .wrap(impl.ruleConfig())
    override val targetControls: List[__stringMin1Max256PatternAZaZ09] = impl
      .targetControls()
      .asScala
      .map { item =>
        item: __stringMin1Max256PatternAZaZ09
      }
      .toList
    override val waitPeriodMs: __integer = impl.waitPeriodMs(): __integer
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.NewGatingRule
  ): zio.aws.route53recoverycontrolconfig.model.NewGatingRule.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-route53recoverycontrolconfig_2.13-5.17.121.3-sources.jar: zio/aws/route53recoverycontrolconfig/model/NewGatingRule.scala <==
package zio.aws.route53recoverycontrolconfig.model
import java.lang.Integer
import zio.aws.route53recoverycontrolconfig.model.primitives.{
  __integer,
  __stringMin1Max64PatternS,
  __stringMin1Max256PatternAZaZ09
}
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class NewGatingRule(
    controlPanelArn: __stringMin1Max256PatternAZaZ09,
    gatingControls: Iterable[__stringMin1Max256PatternAZaZ09],
    name: __stringMin1Max64PatternS,
    ruleConfig: zio.aws.route53recoverycontrolconfig.model.RuleConfig,
    targetControls: Iterable[__stringMin1Max256PatternAZaZ09],
    waitPeriodMs: __integer
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.route53recoverycontrolconfig.model.NewGatingRule = {
    import NewGatingRule.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.NewGatingRule
      .builder()
      .controlPanelArn(
        __stringMin1Max256PatternAZaZ09.unwrap(
          controlPanelArn
        ): java.lang.String
      )
      .gatingControls(gatingControls.map { item =>
        __stringMin1Max256PatternAZaZ09.unwrap(item): java.lang.String
      }.asJavaCollection)
      .name(__stringMin1Max64PatternS.unwrap(name): java.lang.String)
      .ruleConfig(ruleConfig.buildAwsValue())
      .targetControls(targetControls.map { item =>
        __stringMin1Max256PatternAZaZ09.unwrap(item): java.lang.String
      }.asJavaCollection)
      .waitPeriodMs(__integer.unwrap(waitPeriodMs): Integer)
      .build()
  }
  def asReadOnly
      : zio.aws.route53recoverycontrolconfig.model.NewGatingRule.ReadOnly =
    zio.aws.route53recoverycontrolconfig.model.NewGatingRule
      .wrap(buildAwsValue())
}
object NewGatingRule {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.NewGatingRule
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.route53recoverycontrolconfig.model.NewGatingRule =
      zio.aws.route53recoverycontrolconfig.model.NewGatingRule(
        controlPanelArn,
        gatingControls,
        name,
        ruleConfig.asEditable,
        targetControls,
        waitPeriodMs
      )
    def controlPanelArn: __stringMin1Max256PatternAZaZ09
    def gatingControls: List[__stringMin1Max256PatternAZaZ09]
    def name: __stringMin1Max64PatternS
    def ruleConfig
        : zio.aws.route53recoverycontrolconfig.model.RuleConfig.ReadOnly
    def targetControls: List[__stringMin1Max256PatternAZaZ09]
    def waitPeriodMs: __integer
    def getControlPanelArn: ZIO[Any, Nothing, __stringMin1Max256PatternAZaZ09] =
      ZIO.succeed(controlPanelArn)
    def getGatingControls
        : ZIO[Any, Nothing, List[__stringMin1Max256PatternAZaZ09]] =
      ZIO.succeed(gatingControls)
    def getName: ZIO[Any, Nothing, __stringMin1Max64PatternS] =
      ZIO.succeed(name)
    def getRuleConfig: ZIO[
      Any,
      Nothing,
      zio.aws.route53recoverycontrolconfig.model.RuleConfig.ReadOnly
    ] = ZIO.succeed(ruleConfig)
    def getTargetControls
        : ZIO[Any, Nothing, List[__stringMin1Max256PatternAZaZ09]] =
      ZIO.succeed(targetControls)
    def getWaitPeriodMs: ZIO[Any, Nothing, __integer] =
      ZIO.succeed(waitPeriodMs)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.NewGatingRule
  ) extends zio.aws.route53recoverycontrolconfig.model.NewGatingRule.ReadOnly {
    override val controlPanelArn: __stringMin1Max256PatternAZaZ09 =
      zio.aws.route53recoverycontrolconfig.model.primitives
        .__stringMin1Max256PatternAZaZ09(impl.controlPanelArn())
    override val gatingControls: List[__stringMin1Max256PatternAZaZ09] = impl
      .gatingControls()
      .asScala
      .map { item =>
        zio.aws.route53recoverycontrolconfig.model.primitives
          .__stringMin1Max256PatternAZaZ09(item)
      }
      .toList
    override val name: __stringMin1Max64PatternS =
      zio.aws.route53recoverycontrolconfig.model.primitives
        .__stringMin1Max64PatternS(impl.name())
    override val ruleConfig
        : zio.aws.route53recoverycontrolconfig.model.RuleConfig.ReadOnly =
      zio.aws.route53recoverycontrolconfig.model.RuleConfig
        .wrap(impl.ruleConfig())
    override val targetControls: List[__stringMin1Max256PatternAZaZ09] = impl
      .targetControls()
      .asScala
      .map { item =>
        zio.aws.route53recoverycontrolconfig.model.primitives
          .__stringMin1Max256PatternAZaZ09(item)
      }
      .toList
    override val waitPeriodMs: __integer =
      zio.aws.route53recoverycontrolconfig.model.primitives
        .__integer(impl.waitPeriodMs())
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.NewGatingRule
  ): zio.aws.route53recoverycontrolconfig.model.NewGatingRule.ReadOnly =
    new Wrapper(impl)
}
